import pandas as pd
import json
from pymongo.mongo_client import MongoClient


class mongodb_operations:
    def __init__(
        self, client_url: str, database_name: str, collection_name: str = None
    ):
        self.client_url = (client_url,)
        self.database_name = database_name
        self.collection_name = collection_name

    def create_client(self):
        client = MongoClient(self.client_url)
        return client

    def create_database(self):
        client = self.create_client()
        database = client[self.database_name]
        return database

    def create_collection(self, collection=None):
        database = self.create_database()
        collection = database[collection]
        return collection

    def insert_record(self, record: dict, collection_name: str):
        if type(record) == list:
            for data in record:
                if type(data) != dict:
                    raise TypeError("record must be dict")
            collection = self.create_collection(collection_name)
            collection.insert_many(record)
        elif type(record) == dict:
            collection = self.create_collection(collection_name)
            collection.insert_one(record)

    def bulk_insert(self, datafile: str, collection_name: str = None):
        self.path = datafile
        if self.path.endswith(".csv"):
            data = pd.read_csv(self.path, encoding="utf-8")
        elif self.path.endswith(".xlsx"):
            data = pd.read_excel(self.path, encoding="utf-8")

        datajson = json.loads(data.to_json(orient="record"))
        collection = self.create_collection()
        collection.insert_many(datajson)



from setuptools import setup, find_packages
from typing import List

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()


__version__ = "0.0.3"
REPO_NAME = "mongodbconnectorpkg"
PKG_NAME = "databasemongoautomation"
AUTHOR_USER_NAME = "assia"
AUTHOR_EMAIL = "assia.chafii93@gmail.com"

setup(
    name=PKG_NAME,
    version=__version__,
    author=AUTHOR_USER_NAME,
    author_email=AUTHOR_EMAIL,
    description="A python package for connecting with database.",
    long_description=long_description,
    long_description_content="text/markdown",
    url=f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}",
    project_urls={
        "Bug Tracker": f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues",
    },
    package_dir={"": "src"},
    packages=find_packages(where="src"),
)
